/************************************************************************/
/* MCU Initialization                                                   */
/* 2014 cermakk.cz														*/
/*																		*/
/* Initialize the Embedded Platform										*/
/*																		*/
/*																		*/
/* Functions:															*/
/* ---------------														*/
/* mcu_init(); Initialize this SW module								*/
/*																		*/
/*																		*/
/* Default setting														*/
/* ---------------														*/
/* Status LEDs: PE0 green, PE1 red										*/
/* Digital I/O: PORTA (PA0 = DIO0, PA1 = DIO1, ... PA7 = DIO7)			*/
/* Analog I/O: PB1 = AD0, PB2 = AD1, PB3 = DA0							*/
/* Special AD: PB0 = Ubat (Battery Voltage measurement)					*/
/* I2C Interface: PC0 = I2C_SDA, PC1 = I2C_SCL							*/
/* SPI Interface: PC2 = SPI_CS2, PC3 = SPI_CS1, PC4 = SPI_CS0,			*/
/*				  PC5 = SPI_MOSI, PC6 = SPI_MISO, PC7 = SPI_CLK			*/
/* UART Interface: PE2 = UART_RX, PE3 = UART_TX							*/
/* Dedicated functions: PD4 = Buzzer, PD5 = Haptic feedback (Vibrator)	*/
/* Hard-wired IOs: PD0-PD3, PD6-PD7										*/
/* Not connected: PR0-PR1												*/
/************************************************************************/

#ifndef _MCU_H_
#define _MCU_H_ 1


/************************************************************************/
/*                            Definitions                               */
/************************************************************************/
#define LED_PORT_DIRECTION PORTE_DIR
#define LED_PORT PORTE_OUT
#define LED_GREEN 0
#define LED_RED 1
#define DIGITAL_PORT_DIRECTION PORTA_DIR
#define DIGITAL_PORT_OUT PORTA_OUT
#define DIGITAL_PORT_IN PORTA_IN
#define DIGITAL_DEFAULT 0 //0 for Inputs, 1 for Outputs
#define DIO0 0
#define DIO1 1
#define DIO2 2
#define DIO3 3
#define DIO4 4
#define DIO5 5
#define DIO6 6
#define DIO7 7
#define ANALOG_PORT_DIRECTION PORTB_DIR
#define ANALOG_PORT_OUT PORTB_OUT;
#define ANALOG_PORT_IN PORTB_IN;
#define AD0 1
#define AD1 2
#define DA0 3
#define UBAT 0
#define I2C_PORT_DIRECTION PORTC_DIR
#define I2C_PORT_OUT PORTC_OUT
#define I2C_PORT_IN PORTC_IN
#define I2C_DATA 0
#define I2C_SCL 1
#define SPI_PORT_DIRECTION PORTC_DIR
#define SPI_PORT_OUT PORTC_OUT
#define SPI_PORT_IN PORTC_IN
#define SPI_CS2 2
#define SPI_CS1 3
#define SPI_CS0	4
#define SPI_MOSI 5
#define SPI_MISO 6
#define SPI_CLK 7
#define UART_PORT_DIRECTION PORTE_DIR
#define UART_PORT_OUT PORTE_OUT
#define UART_PORT_IN PORTE_IN
#define UART_RX 2
#define UART_TX 3
#define FUNCTIONS_PORT_DIRECTION PORTD_DIR
#define FUNCTIONS_PORT_OUT PORTD_OUT
#define FUNCTIONS_PORT_IN PORTD_IN
#define BUZZER 4
#define HAPTIC 5


// Macros
#define LED_ON_RED LED_PORT&=~(1<<LED_RED)
#define LED_OFF_RED LED_PORT|=(1<<LED_RED)
#define LED_ON_GREEN LED_PORT&=~(1<<LED_GREEN)
#define LED_OFF_GREEN LED_PORT|=(1<<LED_GREEN)




/************************************************************************/
/*                         Public functions                             */
/************************************************************************/




void mcu_init(void);
/*
		mcu initialization
*/


void vibrate_on(void);
/*
	starts motor for haptic feedback
*/


void vibrate_off(void);
/*
	stops the vibrating motor
*/


void buzzer_high(void);
/*
	set the buzzer pin high
	Note: this produce no sound, use it with buzzer_low function
		in loop to produce sound
*/


void buzzer_low(void);
/*
	set the buzzer pin low
*/





/************************************************************************/
/*                               CODE                                   */
/************************************************************************/

void mcu_init(void) //mcu initialization
{

	// use MCU defaults, see ATxmega32A4U datasheet
	DIGITAL_PORT_OUT = DIGITAL_DEFAULT;
	FUNCTIONS_PORT_DIRECTION |= (1<<BUZZER) | (1<<HAPTIC);
	FUNCTIONS_PORT_OUT &= ~( (1<<BUZZER) | (1<<HAPTIC));

}


void vibrate_on(void){
/*
	starts motor for haptic feedback
*/
	FUNCTIONS_PORT_OUT|=(1<<HAPTIC);
}


void vibrate_off(void){
/*
	stops the vibrating motor
*/
	FUNCTIONS_PORT_OUT&=~(1<<HAPTIC);
}

void buzzer_high(void){
/*
	set the buzzer pin high
	Note: this produce no sound, use it with buzzer_low function
		in loop to produce sound
*/
	FUNCTIONS_PORT_OUT|=(1<<BUZZER);
}

void buzzer_low(void){
/*
	set the buzzer pin low
*/
	FUNCTIONS_PORT_OUT&=~(1<<BUZZER);
}

#endif /* _MCU_H_ */