/****************************************************************************/
/* Status LED driver														*/
/* 2014 cermakk.cz															*/
/*																			*/
/* Initialize the LEDs to present the current status of Emb. Platform		*/
/*																			*/
/*																			*/
/* Functions:																*/
/* ---------------															*/
/* status_init(); Initialize this SW module									*/
/* status_set_red(value); Turn on (value>0) or off (value=0) red LED		*/
/* status_set_green(value); Turn on (value>0) or off (value=0) green LED	*/
/*																			*/
/****************************************************************************/
#ifndef _STATUS_H_
#define _STATUS_H_ 1


#include "mcu.h"


//-----------------------------------------------------------------------
//                        Public functions
//-----------------------------------------------------------------------





/*
	initialization of status leds

*/
void status_init(void);


/*
	set red LED to defined value
	parameter value: 0 [off], >0 [on]
*/
void status_set_red(uint8_t value);


/*
	set green LED to defined value
	parameter value: 0 [off], >0 [on]
*/
void status_set_green(uint8_t value);






//-----------------------------------------------------------------------
//                             CODE
//-----------------------------------------------------------------------




void status_init(void) //initialization of status LEDs
{
	
	LED_PORT_DIRECTION |= (1<<LED_GREEN) | (1<<LED_RED); // Set the LED pins on LED Port as outputs
}

void status_set_red(uint8_t value)
{
	if (value)
	{			
		LED_PORT &= ~(1<<LED_RED);//Turn on
	} 
	else
	{
		LED_PORT |= (1<<LED_RED);	//Turn off
	}
}

void status_set_green(uint8_t value)
{
	if (value)
	{
		LED_PORT &= ~(1<<LED_GREEN);//Turn on
	}
	else
	{
		LED_PORT |= (1<<LED_GREEN);	//Turn off
	}
}

#endif /* _STATUS_H_ */